read.quake.mdl: Read Quake model in MDL format.

View source: R/read_model_mdl.R

read.quake.mdlR Documentation

Read Quake model in MDL format.

Description

Read Quake model in MDL format.

Usage

read.quake.mdl(filepath, do_checks = FALSE)

Arguments

filepath

character string, the path to the MDL file

do_checks

logical, whether to perform some sanity checks on the data and warn on suspicious results.

Note

Ignore this function, it will be moved to a different package.

Examples

## Not run: 
   mdlf = "~/data/q1_pak/progs/quaddama.mdl"
   mdl = read.quake.mdl(mdlf);

## End(Not run)


wal documentation built on Aug. 22, 2026, 5:07 p.m.