wad_dir.fileext.mapping: Get file extensions for WAD dir entry type strings.

View source: R/read_wad.R

wad_dir.fileext.mappingR Documentation

Get file extensions for WAD dir entry type strings.

Description

Get file extensions for WAD dir entry type strings.

Usage

wad_dir.fileext.mapping()

Value

named list, which maps wad_dir.types.strings to file extensions. Afaik, there are not standard file extensions for these file types, and I made the ones used here up.

See Also

wad_dir.types.string


wal documentation built on Aug. 22, 2026, 5:07 p.m.